@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -113,7 +113,6 @@ class MiniPlayer(Handy.WindowHandle, SizeAllocationHelper, SignalsHelper):
             @param reveal as bool
         """
         if reveal:
-            self.__update_progress_visibility()
             self.__revealer.set_reveal_child(True)
             emit_signal(self, "revealed", True)
             self.__progress_widget.update()
@@ -179,6 +178,9 @@ class MiniPlayer(Handy.WindowHandle, SizeAllocationHelper, SignalsHelper):
         """
         if player.current_track.id is None:
             self.__on_artwork(None)
+            self.__previous_artwork_id = None
+            self.reveal(False)
+            self.hide()
             return
 
         same_artwork = self.__previous_artwork_id ==\
@@ -235,15 +237,6 @@ class MiniPlayer(Handy.WindowHandle, SizeAllocationHelper, SignalsHelper):
 #######################
 # PRIVATE             #
 #######################
-    def __update_progress_visibility(self):
-        """
-            Update progress bar visibility
-        """
-        if App().player.current_track.id is not None:
-            self.__progress_widget.show()
-        else:
-            self.__progress_widget.hide()
-
     def __set_widgets_position(self):
         """
             Add label widget to wanted UI part
